@@ -46,6 +46,13 @@ void init() {
     auto installer = new updater::RunInstaller;
 #ifdef APP_WIN
     installer->setArguments({"/S"});
+    installer->setRelaunchArguments({"/run"});
+#endif
+#ifdef APP_LINUX
+    installer->setCommand({"dpkg"});
+    installer->setArguments({"-i", "%filename%"});
+    installer->setRunAsAdmin(true);
+    installer->setAutoRestart(true);
 #endif
     updater->setInstaller(installer);
 
